"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
    return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var image_palette_extractor_1 = require("./image-palette-extractor");
var mockImage = function () {
    var canvas = document.createElement('canvas');
    canvas.width = 300;
    canvas.height = 150;
    var ctx = canvas.getContext('2d');
    var colors = ['red', 'green', 'blue'];
    colors.forEach(function (_color, index, list) {
        var canvasWidth = canvas.width, canvasHeight = canvas.height;
        var width = canvasWidth / list.length;
        var height = canvasHeight;
        var x = index * width;
        var y = 0;
        ctx.fillStyle = colors[index];
        ctx.fillRect(x, y, width, height);
    });
    return canvas.toDataURL();
};
describe('ColorPalette - Unit tests', function () {
    // Mocks
    var mockedImage = new Image();
    mockedImage.src = mockImage();
    afterEach(function () {
        jest.clearAllMocks();
    });
    describe('getColors', function () {
        it('should extract a color palette with two colors by default', function () { return __awaiter(void 0, void 0, void 0, function () {
            var expectedResult, resultPalette;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        expectedResult = [
                            '#ff0000ff', // Vermelho
                            '#008000ff', // Verde
                        ];
                        return [4 /*yield*/, image_palette_extractor_1.ColorPalette.getColors(mockedImage.src)];
                    case 1:
                        resultPalette = _a.sent();
                        // Assert
                        expect(resultPalette.length).toBe(2);
                        expect(resultPalette).toEqual(expectedResult);
                        return [2 /*return*/];
                }
            });
        }); });
        it('should extract a color palette with the specified number of colors', function () { return __awaiter(void 0, void 0, void 0, function () {
            var expectedResult, numOfColorsToExtract, resultPalette;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        expectedResult = [
                            '#ff0000ff', // Vermelho
                            '#008000ff', // Verde
                            '#0000ffff', // Azul
                        ];
                        numOfColorsToExtract = 3;
                        return [4 /*yield*/, image_palette_extractor_1.ColorPalette.getColors(mockedImage.src, numOfColorsToExtract)];
                    case 1:
                        resultPalette = _a.sent();
                        // Assert
                        expect(resultPalette.length).toBe(numOfColorsToExtract);
                        expect(resultPalette).toEqual(expectedResult);
                        return [2 /*return*/];
                }
            });
        }); });
        it('should reject the promise if the image fails to load', function () { return __awaiter(void 0, void 0, void 0, function () {
            var promise;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        promise = image_palette_extractor_1.ColorPalette.getColors('');
                        /** Assert */
                        return [4 /*yield*/, expect(promise).rejects.toEqual(jasmine.any(String))];
                    case 1:
                        /** Assert */
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
    });
    describe('_countPixelColors', function () {
        it('should count colors excluding white and transparent', function () {
            var pixelData = new Uint8ClampedArray([
                255,
                255,
                255,
                255, // White pixel (excluded)
                255,
                0,
                0,
                255, // Red pixel
                0,
                0,
                0,
                0, // Transparent pixel (excluded)
                255,
                0,
                0,
                255, // Red pixel
            ]);
            var result = image_palette_extractor_1.ColorPalette['_countPixelColors'](pixelData);
            expect(Object.keys(result)).toHaveLength(1);
            expect(result['255,0,0,255']).toBe(2);
        });
    });
    describe('_sortColorsByCount', function () {
        it('should sort colors by count in descending order', function () {
            var colorCounts = {
                '255,0,0,255': 3,
                '0,255,0,255': 1,
                '0,0,255,255': 2,
            };
            var result = image_palette_extractor_1.ColorPalette['_sortColorsByCount'](colorCounts);
            expect(result).toHaveLength(3);
            expect(result[0]).toEqual([255, 0, 0, 255]);
            expect(result[1]).toEqual([0, 0, 255, 255]);
            expect(result[2]).toEqual([0, 255, 0, 255]);
        });
    });
    describe('_getRgbaColorString', function () {
        it('should convert RGBA array to CSS string format', function () {
            var rgba = [255, 128, 0, 255];
            var result = image_palette_extractor_1.ColorPalette['_getRgbaColorString'](rgba);
            expect(result).toBe('rgba(255, 128, 0, 1)');
        });
        it('should handle alpha channel conversion', function () {
            var rgba = [255, 128, 0, 128];
            var result = image_palette_extractor_1.ColorPalette['_getRgbaColorString'](rgba);
            expect(result).toBe('rgba(255, 128, 0, 0.5019607843137255)');
        });
    });
});
//# sourceMappingURL=image-palette-extractor.spec.js.map