import { type TRgba } from '../app/image-palette-extractor';
/**
 * rgbToHex
 *
 * Converts RGB color values to a hexadecimal color string.
 *
 * @param r - The red color value (0-255).
 *
 * @param g - The green color value (0-255).
 *
 * @param b - The blue color value (0-255).
 *
 * @returns The hexadecimal color string in the format `#RRGGBB`.
 *
 * @throws Will throw an error if any RGB value is out of range (0-255).
 */
export declare const rgbToHex: (r: number, g: number, b: number) => string;
/**
 * rgbaToHex
 *
 * Converts RGBA color values to a hexadecimal color string.
 *
 * @param r - The red color value (0-255).
 *
 * @param g - The green color value (0-255).
 *
 * @param b - The blue color value (0-255).
 *
 * @param a - The alpha value (0-1).
 *
 * @returns The hexadecimal color string in the format `#RRGGBBAA`.
 *
 * @throws Will throw an error if any RGB value is out of range (0-255), or if alpha is out of range (0-1).
 */
export declare const rgbaToHex: (r: number, g: number, b: number, a: number) => string;
/**
 * _rgbToLab
 *
 * Converts RGB color to Lab color space.
 *
 * @see https://zschuessler.github.io/DeltaE/learn/
 *
 * @param r - The red color value (0-255).
 *
 * @param g - The green color value (0-255).
 *
 * @param b - The blue color value (0-255).
 */
export declare const rgbToLab: (r: number, g: number, b: number) => [number, number, number];
/**
 * extractRgbAsTuple
 *
 * Extract the numbers of the provided rgba string and return the tuple containing the values and the alpha.
 *
 * @param rbgaString - The Rgba string value (rgba(0,0,0,0)).
 *
 * @returns A tuple of type `TRgba`
 */
export declare const extractRgbAsTuple: (rbgaString: string) => TRgba;
/**
 * getLuminanceFromHex
 *
 * Calculates the luminance of a color from its hexadecimal representation.
 *
 * @remarks
 *
 * If the luminance is greater than 0.5, the background is
 * considered light, so you should use a dark text color.
 * If the luminance is less than or equal to 0.5, the
 * background is considered dark, so you should use a light text color.
 *
 * @param hex - The hexadecimal color string.
 *
 * @returns The luminance of the color.
 */
export declare const getLuminanceFromHex: (hex: string) => number;
//# sourceMappingURL=ColorUtils.d.ts.map